@@ -4,8 +4,10 @@
 #' Europe PMC RESTful Web Service.
 #'
 #' @inheritParams epmc_refs
-#' @param db character, restrict the response to a specific database:
+#' @param db character, specify database:
 #'  \describe{
+#'  \item{'ARXPR'}{Array Express, a database of functional genomics experiments
+#'     \url{https://www.ebi.ac.uk/arrayexpress/}}
 #'  \item{'CHEBI'}{a database and ontology of chemical entities of biological
 #'      interest \url{http://www.ebi.ac.uk/chebi/}}
 #'   \item{'CHEMBL'}{a database of bioactive drug-like small molecules
@@ -27,9 +29,8 @@
 #'      resource of protein sequence and functional information
 #'   \url{http://www.uniprot.org/}}
 #'   \item{'PRIDE'}{PRIDE Archive - proteomics data repository
-#'   \url{https://www.ebi.ac.uk/pride/archive/}}
-#'   }
-
+#'   \url{https://www.ebi.ac.uk/pride/archive/}}}
+#'
 #' @return Cross-references as data.frame
 #' @examples
 #'   \dontrun{
@@ -44,9 +45,8 @@ epmc_db <- function(ext_id = NULL,
                     db = NULL,
                     limit = 100,
                     verbose = TRUE) {
-  if (is.null(ext_id))
-    stop("Please provide a publication id")
-  # build request
+  # validate input
+  val_input(ext_id, data_src, limit, verbose)
   if (is.null(db))
     stop("Please restrict reponse to a database")
   if (!toupper(db) %in% supported_db)
@@ -59,65 +59,77 @@ epmc_db <- function(ext_id = NULL,
         paste0(supported_db, collapse = ", ")
       )
     )
-  if (!tolower(data_src) %in% supported_data_src)
-    stop(
-      paste0(
-        "Data source '",
-        data_src,
-        "' not supported. Try one of the
-        following sources: ",
-        paste0(supported_data_src, collapse = ", ")
-      )
-    )
-  stopifnot(is.numeric(limit))
-  stopifnot(is.logical(verbose))
   # build request
-  req_method <- "databaseLinks"
-  path <- paste(rest_path(), data_src, ext_id, req_method, db,
-                "json", sep = "/")
-  doc <- rebi_GET(path = path)
-  hit_count <- doc$hitCount
+  path <- mk_path(data_src, ext_id, req_method = "databaseLinks")
+  # how many records are found?
+  hit_count <- get_counts(path = path, database = db)
   if (hit_count == 0) {
-    message("Sorry, no links found")
-    result <- NULL
+    message("No links found")
+    out <- NULL
   } else {
-    if (verbose == TRUE)
-      message(paste0(
-        hit_count,
-        " records found. Returning ",
-        ifelse(hit_count <= limit, hit_count, limit)
-      ))
-    paths <-
-      make_path(
-        hit_count = hit_count,
+    # provide info
+    msg(hit_count = hit_count,
         limit = limit,
-        ext_id = ext_id,
-        data_src = data_src,
-        req_method = req_method,
-        type = db
-      )
-    out <- lapply(paths, function(x) {
-      doc <- rebi_GET(path = x)
-      plyr::ldply(
-        doc$dbCrossReferenceList$dbCrossReference$dbCrossReferenceInfo,
-        data.frame,
-        stringsAsFactors = FALSE,
-        .id = NULL
-      )
-    })
-    #combine all into one
-    result <- jsonlite::rbind_pages(out) %>%
-      dplyr::as_data_frame()
-    # return
-    attr(result, "hit_count") <- hit_count
+        verbose = verbose)
+    # request records and parse them
+    # request records and parse them
+    if (hit_count >= limit) {
+      req <-
+        rebi_GET(path = path,
+                 query = list(format = "json", pageSize = limit, database = db))
+      out <- dplyr::bind_cols(req$dbCrossReferenceList$dbCrossReference$dbCrossReferenceInfo)
+    } else {
+      query <-
+        make_path(hit_count = hit_count,
+                  limit = limit, database = db)
+      out <- purrr::map_df(query, function(x) {
+        req <- rebi_GET(path = path, query = x)
+        dplyr::bind_cols(req$dbCrossReferenceList$dbCrossReference$dbCrossReferenceInfo)
+      })
+    }
+    dplyr::as_data_frame(out)
+    # return hit count as attribute
+    attr(out, "hit_count") <- hit_count
   }
-  result
+  out
 }
 
 
+
+#
+#
+#     paths <-
+#       make_path(
+#         hit_count = hit_count,
+#         limit = limit,
+#         ext_id = ext_id,
+#         data_src = data_src,
+#         req_method = req_method,
+#         database = db
+#       )
+#     out <- lapply(paths, function(x) {
+#       doc <- rebi_GET(path = x)
+#       plyr::ldply(
+#         doc$dbCrossReferenceList$dbCrossReference$dbCrossReferenceInfo,
+#         data.frame,
+#         stringsAsFactors = FALSE,
+#         .id = NULL
+#       )
+#     })
+#     #combine all into one
+#     result <- jsonlite::rbind_pages(out) %>%
+#       dplyr::as_data_frame()
+#     # return
+#     attr(result, "hit_count") <- hit_count
+#   }
+#   result
+# }
+
+
 # supported dbs
 supported_db <-
-  c("CHEBI",
+  c("ARXPR",
+    "CHEBI",
     "CHEMBL",
     "EMBL",
     "INTACT",
