@@ -13,7 +13,8 @@ test_that("epmc_db_count returns", {
 
 
   # fails correctly
-  expect_error(epmc_db_count("22326070"),
+  expect_message(epmc_db_count("22326070"),
                "Nothing found")
+  expect_null(epmc_db_count("22326070"))
   expect_error(epmc_db_count("13814508", data_src = "abc"))
 })
